<?php


namespace Fastrack\Utilities;


use PlatoCreative\Imgix\Imgix;
use SilverStripe\Assets\File;
use SilverStripe\Core\Config\Config;
use SilverStripe\Core\Environment;
use SilverStripe\Forms\FieldList;
use SilverStripe\ORM\DataObject;

class ModelUtilities
{

	public static function hideHasOneFields(DataObject $dataObject, FieldList $fieldList)
	{
		foreach ($dataObject->hasOne() as $key => $value) {
			$fieldList->removeByName($key . 'ID');
		}
		return $fieldList;
	}

	/**
	 * @deprecated
	 *
	 * @param DataObject $dataObject
	 * @param FieldList $fieldList
	 * @return FieldList
	 */
	public static function hideFields(DataObject $dataObject, FieldList $fieldList)
	{
		$class = substr(strrchr($dataObject->getClassName(), '\\'), 1);
		$setting = Environment::getEnv(join('_', ['HIDDEN_FIELDS', $class]));
		if ($setting) {
			$fieldKeys = explode(',', $setting);
			foreach ($fieldKeys as $fieldKey) {
				self::hideField($fieldList, $fieldKey);
			}
		}
		return $fieldList;
	}

	public static function hideConfigFields($class, FieldList $fields)
	{
		$fieldKeys = Config::inst()->get($class, 'hidden_fields');
		if (!$fieldKeys) return;
		foreach ($fieldKeys as $fieldKey) {
			self::hideField($fields, $fieldKey);
		}
	}

	private static function hideField(FieldList $fieldList, string $fieldKey)
	{
		if (str_contains($fieldKey, '.')) {
			$components = explode('.', $fieldKey);
			$field = [array_pop($components)];
			$fieldList->removeFieldsFromTab(implode('.', $components), $field);
		} else {
			$fieldList->removeByName($fieldKey);
		}
	}

}
